@@ -25,9 +25,11 @@ routes = [
   Route('/', handler='handlers.RootHandler'),  
   Route('/profile', handler='handlers.ProfileHandler', name='profile'),
   
-  Route('/auth/<provider>', handler='handlers.AuthHandler:_simple_auth', name='auth_login'),
-  Route('/auth/<provider>/callback', handler='handlers.AuthHandler:_auth_callback', name='auth_callback'),
-  Route('/logout', handler='handlers.AuthHandler:logout', name='logout')
+  Route('/logout', handler='handlers.AuthHandler:logout', name='logout'),
+  Route('/auth/<provider>', 
+    handler='handlers.AuthHandler:_simple_auth', name='auth_login'),
+  Route('/auth/<provider>/callback', 
+    handler='handlers.AuthHandler:_auth_callback', name='auth_callback')
 ]
 
 app = WSGIApplication(routes, config=app_config, debug=True)
