@@ -21,10 +21,6 @@ except ImportError:
     from django.utils import simplejson as json
     # at this point ImportError will be raised 
     # if none of the above could be imported
-    
-# already in the App Engine libs, see app.yaml on how to specify libraries
-# need this for providers like LinkedIn
-from lxml import etree
 
 # it's a OAuth 1.0 spec even though the lib is called oauth2
 import oauth2 as oauth1
@@ -72,22 +68,7 @@ class SimpleAuthHandler(object):
   e.g. webapp2.RequestHandler. See README for getting started and 
   a usage example, or look through the code. It really is simple.
 
-  Docs on authentication flow of various providers:
-
-  Google auth
-  http://code.google.com/apis/accounts/docs/OAuth2WebServer.html
-  
-  Facbook auth
-  http://developers.facebook.com/docs/authentication/
-  
-  LinkedIn auth.
-  https://developer.linkedin.com/documents/linkedins-oauth-details
-  
-  Windows Live.
-  http://msdn.microsoft.com/en-us/library/hh243648.aspx#user
-  
-  Twtitter.
-  https://dev.twitter.com/docs/auth/oauth
+  See README for docs on authentication flows.
   """
   
   PROVIDERS = {
@@ -95,8 +76,8 @@ class SimpleAuthHandler(object):
       'https://accounts.google.com/o/oauth2/auth?{0}', 
       'https://accounts.google.com/o/oauth2/token'),
     'windows_live': ('oauth2',
-      'https://oauth.live.com/authorize?{0}',
-      'https://oauth.live.com/token'),
+      'https://login.live.com/oauth20_authorize.srf?{0}',
+      'https://login.live.com/oauth20_token.srf'),
     'facebook'    : ('oauth2',
       'https://www.facebook.com/dialog/oauth?{0}',
       'https://graph.facebook.com/oauth/access_token'),
@@ -411,6 +392,15 @@ class SimpleAuthHandler(object):
     where <fields> is something like
     (id,first-name,last-name,picture-url,public-profile-url,headline)
     """
+    try:
+        # already in the App Engine libs, see app.yaml on how to specify
+        # libraries need this for providers like LinkedIn
+        from lxml import etree
+    except ImportError:
+        logging.error('requirement `lxml.etree` was not provided. please '
+                      'make sure you have enabled it in app.yaml')
+        raise
+
     token = oauth1.Token(key=auth_info['oauth_token'], 
                          secret=auth_info['oauth_token_secret'])
     client = self._oauth1_client(token, key, secret)
